.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. How to do various tasks with TotalDepth

##########################################
HOWTOs: What TotalDepth can do for you
##########################################

This describes how TotalDepth can help you with various tasks when dealing with petrophysical data.

.. toctree::
    :maxdepth: 3
    
    archive
    las_archive
    lis_archive
    rp66v1_archive
    to_las
   